@@ -10,7 +10,7 @@ use Carp qw( croak carp );
 use File::ShareDir ();
 
 # ABSTRACT: Tiny C Compiler for FFI
-our $VERSION = '0.20'; # VERSION
+our $VERSION = '0.21'; # VERSION
 
 
 sub _dlext ()
@@ -277,7 +277,7 @@ sub get_symbol
     my $size = _relocate($self, undef);
     $self->{store} = malloc($size);
     my $r = _relocate($self, $self->{store});
-    FFI::TinyCC::Exception->new($self) if $r == -1;
+    die FFI::TinyCC::Exception->new($self) if $r == -1;
     $self->{relocate} = 1;
   }
   _get_symbol($self, $symbol_name);
@@ -371,7 +371,7 @@ FFI::TinyCC - Tiny C Compiler for FFI
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -732,7 +732,15 @@ under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+aero
+
+Dylan Cali (calid)
+
+pipcet
 
 =head1 COPYRIGHT AND LICENSE
 
